==> Totem%20Utils-1.1.2-1.21-sources.jar: CCPCT/TotemUtils/util/Logic.java <==
package CCPCT.TotemUtils.util;

import CCPCT.TotemUtils.config.ModConfig;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2846;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3414;
import net.minecraft.class_3419;

public class Logic {
    public static boolean overlayactive = false;
    public static boolean totemCountActive = false;
    public static int totemCountValue = 0;

    public static void refillTotem() {
        if (!Packets.isQueueEmpty()) return;
        class_310 client = class_310.method_1551();
        class_1657 player = client.field_1724;

        if (player == null) return;
        int slot = Logic.getSlotWithSpareTotem(0);
        if (ModConfig.get().replaceMainHandTotem && player.method_6047().method_7960() && slot >= 9){
            // move totem to mainhand
            Chat.colour("Refilling mainhand!", "green");

            Packets.swapItem(slot, player.method_31548().field_7545, true);
            Packets.sendNull();
            slot = Logic.getSlotWithSpareTotem(1);
        }

        // move totem to offhand
        if (totemOnOffhand()) return;
        Chat.colour("Refilling Offhand!", "green");
        if (slot == -1) {
            Chat.colour("No totem!", "red");
            return;
        }
        moveTotemToOffhand(slot);
    }

    public static boolean totemOnOffhand(){
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return false;
        return player.method_31548().field_7544.getFirst().method_7909() == class_1802.field_8288;
    }

    public static int getTotemCount() {
        //prefer take from inventory
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return -1;
        //take from hotbar
        int count = 0;
        for (int i = 0; i < player.method_31548().field_7547.size(); i++) {
            class_1799 stack = player.method_31548().field_7547.get(i);
            if (!stack.method_7960() && stack.method_7909() == class_1802.field_8288) {
                count++;
            }
        }
        // count offhand
        class_1799 stack = player.method_31548().field_7544.getFirst();
        if (!stack.method_7960() && stack.method_7909() == class_1802.field_8288) count++;

        return count;
    }

    private static int getSlotWithSpareTotem(int ignoring) {
        //prefer take from inventory
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return -1;
        for (int i = 9; i < player.method_31548().field_7547.size(); i++) {
            class_1799 stack = player.method_31548().field_7547.get(i);

            if (!stack.method_7960() && stack.method_7909() == class_1802.field_8288) {
                if (ignoring > 0){
                    ignoring--;
                } else {
                    return i;
                }
            }
        }
        //take from hotbar
        for (int i = 0; i < 9; i++) {
            class_1799 stack = player.method_31548().field_7547.get(i);

            if (!stack.method_7960() && stack.method_7909() == class_1802.field_8288) {
                if (ignoring > 0){
                    ignoring--;
                } else {
                    return i;
                }
            }
        }
        return -1;
    }

    private static void moveTotemToOffhand(int fromSlot) {
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return;
        class_1661 inventory = player.method_31548();

        if (fromSlot < 9) {
            // hotbar case
            // Select Totem Slot
            Packets.selectHotbarSlot(fromSlot,false);

            // Swap Totem to Offhand
            Packets.sendPacket(new class_2846(
                    class_2846.class_2847.field_12969,
                    class_2338.field_10980,
                    class_2350.field_11033
            ),true);

            // Restore Old Hotbar Slot
            Packets.selectHotbarSlot(inventory.field_7545,true);
            //delay
            Packets.sendNull();
            Packets.sendNull();

        } else {
            Packets.swapItem(fromSlot,40,false);
            Packets.sendNull();
        }
    }
    public static void stopTotemSound() {
        class_310 client = class_310.method_1551();
        if (client.field_1724 != null) {
            client.method_1483().method_4875(
                    class_2960.method_60654("minecraft:item.totem.use"),
                    class_3419.field_15248
            );
        }
    }
    public static void playCustomSound() {
        class_310 client = class_310.method_1551();
        if (client.field_1724 != null) {
            client.field_1724.method_5783(class_3414.method_47908(class_2960.method_60654(ModConfig.get().customSoundName)),ModConfig.get().customSoundVolume,1.0f);
        }
    }
}

==> Totem%20Utils-1.2.0-1.21-sources.jar: CCPCT/TotemUtils/util/Logic.java <==
package CCPCT.TotemUtils.util;

import CCPCT.TotemUtils.config.ModConfig;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2846;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3414;
import net.minecraft.class_3419;

public class Logic {
    public static boolean overlayactive = false;
    public static boolean totemCountActive = false;
    public static int totemCountValue = 0;

    public static void refillTotem() {
        if (!Packets.isQueueEmpty()) return;
        class_310 client = class_310.method_1551();
        class_1657 player = client.field_1724;
        if (player == null) return;

        class_1799 mainhandStack = player.method_6047();
        int slot = Logic.getSlotWithSpareTotem(0);

        // replenish main hand
        if (ModConfig.get().replenishMainHandTotem && mainhandStack.method_7960()){
            if (slot==-1) {
                Chat.send("§cNo totem!", true);
            }
            if (slot >= 9) {
                // move totem from inv to mainhand
                Chat.send("§aRefilled mainhand", true);
                Packets.swapItem(slot, player.method_31548().field_7545, true);
                Packets.sendNull();
                slot = Logic.getSlotWithSpareTotem(1);
            } // dont allow moving 2 items by pressing 1 button!!
        }


        // move totem to offhand
        if (totemOnOffhand()) {
            if (ModConfig.get().replenishGeneralItem){
                // replenish item if totem on offhand
                if (mainhandStack.method_7947()==mainhandStack.method_7914()||mainhandStack.method_7947()>8) return; // dont need to replenish
                int replenishSlot = getSlotWithSpareItem(mainhandStack.method_7909(),0);
                if (replenishSlot<=8) return; // cant replenish
                int hotslot = player.method_31548().field_7545 + 36;
                Packets.clickItem(hotslot, class_1799.field_8037,true);
                Packets.sendNull(2);
                Packets.doubleClickItem(hotslot,mainhandStack,true);
                Packets.sendNull(2);
                mainhandStack.method_7939(Math.min(mainhandStack.method_7914(),getItemCount(mainhandStack.method_7909(),false))); //update content
                Packets.clickItem(hotslot, mainhandStack,true);
                Packets.sendNull();


            }
            return;
        }
        Chat.send("§aRefilled offhand",true);
        if (slot == -1) {
            Chat.send("§cNo Totem!!",true);
            return;
        }
        moveTotemToOffhand(slot);
    }

    public static boolean totemOnOffhand(){
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return false;
        return player.method_31548().field_7544.getFirst().method_7909() == class_1802.field_8288;
    }
    public static int getTotemCount() {
        return getItemCount(class_1802.field_8288, true);
    }

    public static int getItemCount(class_1792 item, boolean offhand) {
        //prefer take from inventory
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return -1;
        //take from hotbar
        int count = 0;
        for (int i = 0; i < player.method_31548().field_7547.size(); i++) {
            class_1799 stack = player.method_31548().field_7547.get(i);
            if (!stack.method_7960() && stack.method_7909() == item) {
                count+=stack.method_7947();
            }
        }
        // count offhand
        class_1799 stack = player.method_31548().field_7544.getFirst();
        if (offhand && !stack.method_7960() && stack.method_7909() == item) count+=stack.method_7947();

        return count;
    }

    private static int getSlotWithSpareTotem(int ignoring) {
        return getSlotWithSpareItem(class_1802.field_8288, ignoring);
    }

    private static int getSlotWithSpareItem(class_1792 item, int ignoring) {
        //prefer take from inventory
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return -1;
        for (int i = 9; i < player.method_31548().field_7547.size(); i++) {
            class_1799 stack = player.method_31548().field_7547.get(i);

            if (!stack.method_7960() && stack.method_7909() == item) {
                if (ignoring > 0){
                    ignoring--;
                } else {
                    return i;
                }
            }
        }
        //take from hotbar
        for (int i = 0; i < 9; i++) {
            class_1799 stack = player.method_31548().field_7547.get(i);

            if (!stack.method_7960() && stack.method_7909() == item) {
                if (ignoring > 0){
                    ignoring--;
                } else {
                    return i;
                }
            }
        }
        return -1;
    }

    private static void moveTotemToOffhand(int fromSlot) {
        class_1657 player = class_310.method_1551().field_1724;
        if (player == null) return;
        class_1661 inventory = player.method_31548();

        if (fromSlot < 9) {
            // hotbar case
            // Select Totem Slot
            Packets.selectHotbarSlot(fromSlot,true);

            // Swap Totem to Offhand
            Packets.sendPacket(new class_2846(
                    class_2846.class_2847.field_12969,
                    class_2338.field_10980,
                    class_2350.field_11033
            ),true);

            // Restore Old Hotbar Slot
            Packets.selectHotbarSlot(inventory.field_7545,true);
            //delay
            Packets.sendNull();
            Packets.sendNull();

        } else {
            Packets.swapItem(fromSlot,40,true);
            Packets.sendNull();
        }
    }
    public static void stopTotemSound() {
        class_310 client = class_310.method_1551();
        if (client.field_1724 != null) {
            client.method_1483().method_4875(
                    class_2960.method_60654("minecraft:item.totem.use"),
                    class_3419.field_15248
            );
        }
    }
    public static void playCustomSound() {
        class_310 client = class_310.method_1551();
        if (client.field_1724 != null) {
            client.field_1724.method_5783(class_3414.method_47908(class_2960.method_60654(ModConfig.get().customSoundName)),ModConfig.get().customSoundVolume,1.0f);
        }
    }
}
